==> network-1.1.0-sources.jar: cn/sinlmao/commons/network/tools/IPTool.java <==
/**
 * Copyright (c) 2019, Sinlmao (888@1st.com).
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package cn.sinlmao.commons.network.tools;

import javax.servlet.http.HttpServletRequest;

/**
 * 从HttpServletRequest获得IP地址类
 *
 * @program: Sinlmao Commons Network Utils
 * @description: 从HttpServletRequest获得IP地址类
 * @author: Sinlmao
 * @create: 2019-08-01 11:11
 */
public class IPTool {

    /**
     * 通过HttpServletRequest返回客户端IP地址
     *
     * @param request HttpServletRequest
     * @return IP String
     * @throws Exception
     */
    public static String getRealIP(HttpServletRequest request) {
        String ip = request.getHeader("x-forwarded-for");
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        return ip;
    }

    /**
     * 通过HttpServletRequest返回客户端IP地址
     *
     * @param request HttpServletRequest
     * @return IP String
     */
    public static String getRealIP_V2(HttpServletRequest request) {
        String accessIP = request.getHeader("x-forwarded-for");
        if (null == accessIP)
            return request.getRemoteAddr();
        return accessIP;
    }
}

==> network-1.2.1-sources.jar: cn/sinlmao/commons/network/tools/IPTool.java <==
/**
 * Copyright (c) 2019, Sinlmao (888@1st.com).
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package cn.sinlmao.commons.network.tools;

import javax.servlet.http.HttpServletRequest;

/**
 * 从HttpServletRequest获得IP地址类
 *
 * @program Sinlmao Commons Network Utils
 * @description 从HttpServletRequest获得IP地址类
 * @author Sinlmao
 * @create 2019-08-01 11:11
 */
public class IPTool {

    /**
     * 通过HttpServletRequest返回客户端IP地址
     *
     * @param request HttpServletRequest
     * @return IP String
     * @throws Exception
     */
    public static String getRealIP(HttpServletRequest request) {
        String ip = request.getHeader("x-forwarded-for");
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        return ip;
    }

    /**
     * 通过HttpServletRequest返回客户端IP地址
     *
     * @param request HttpServletRequest
     * @return IP String
     */
    public static String getRealIP_V2(HttpServletRequest request) {
        String accessIP = request.getHeader("x-forwarded-for");
        if (null == accessIP)
            return request.getRemoteAddr();
        return accessIP;
    }
}
